==> libKF5KDEGames-devel-15.04.3-1.tar.xz: usr/lib/cmake/KF5KDEGames/KF5KDEGamesLibraryDepends-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5KDEGames" for configuration "RelWithDebInfo"
set_property(TARGET KF5KDEGames APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(KF5KDEGames PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libKF5KDEGames.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "Qt5::Xml;Qt5::Svg;Qt5::Quick;KF5::Declarative;KF5::KIOWidgets;KF5::NewStuff;KF5::IconThemes;KF5::GuiAddons;KF5::KDELibs4Support"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/cygKF5KDEGames-6.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5KDEGames )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5KDEGames "${_IMPORT_PREFIX}/lib/libKF5KDEGames.dll.a" "${_IMPORT_PREFIX}/bin/cygKF5KDEGames-6.dll" )

# Import target "KF5KDEGamesPrivate" for configuration "RelWithDebInfo"
set_property(TARGET KF5KDEGamesPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(KF5KDEGamesPrivate PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libKF5KDEGamesPrivate.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "KF5::DNSSD;KF5::NewStuff;KF5::Archive"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/cygKF5KDEGamesPrivate-1.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5KDEGamesPrivate )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5KDEGamesPrivate "${_IMPORT_PREFIX}/lib/libKF5KDEGamesPrivate.dll.a" "${_IMPORT_PREFIX}/bin/cygKF5KDEGamesPrivate-1.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> libKF5KDEGames-devel-17.12.3-1.tar.xz: usr/lib/cmake/KF5KDEGames/KF5KDEGamesLibraryDepends-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5KDEGames" for configuration "RelWithDebInfo"
set_property(TARGET KF5KDEGames APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(KF5KDEGames PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libKF5KDEGames.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "Qt5::Xml;Qt5::Svg;Qt5::Quick;KF5::Declarative;KF5::KIOWidgets;KF5::NewStuff;KF5::IconThemes;KF5::GuiAddons"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/cygKF5KDEGames-7.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5KDEGames )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5KDEGames "${_IMPORT_PREFIX}/lib/libKF5KDEGames.dll.a" "${_IMPORT_PREFIX}/bin/cygKF5KDEGames-7.dll" )

# Import target "KF5KDEGamesPrivate" for configuration "RelWithDebInfo"
set_property(TARGET KF5KDEGamesPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(KF5KDEGamesPrivate PROPERTIES
  IMPORTED_IMPLIB_RELWITHDEBINFO "${_IMPORT_PREFIX}/lib/libKF5KDEGamesPrivate.dll.a"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELWITHDEBINFO "KF5::DNSSD;KF5::NewStuff;KF5::Archive"
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/cygKF5KDEGamesPrivate-1.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5KDEGamesPrivate )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5KDEGamesPrivate "${_IMPORT_PREFIX}/lib/libKF5KDEGamesPrivate.dll.a" "${_IMPORT_PREFIX}/bin/cygKF5KDEGamesPrivate-1.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
